{
	"name" : "Products with multi-level variants",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Generic Modules/Inventory Control",
	"depends" : ["product"],
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : [],
	"active": False,
	"installable": False
}
